# dirigo-zaber
`dirigo-zaber` provides Zaber motorized stage functionality in [Dirigo](https://dirigo.readthedocs.io/). 

> **Note**  
> This is a hardware plugin for Dirigo and is not intended to be used as a standalone library. 

[![PyPI](https://img.shields.io/pypi/v/dirigo-zaber)](https://pypi.org/project/dirigo-zaber/)


## Tested models
- X-LSM-E


## Installation
(Recommended) Install [Zaber Launcher](https://www.zaber.com/zaber-launcher) and verify that your device is recognized and function.

```bash
pip install dirigo-zaber
```

If not already installed, this command will install the official [Zaber Python library](https://pypi.org/project/zaber-motion/).


## Legal Disclaimer
This library is provided "as is" without any warranties, express or implied, including but not limited to the implied warranties of merchantability, fitness for a particular purpose, or non-infringement. The authors are not responsible for any damage to hardware, data loss, or other issues arising from the use or misuse of this library. Users are advised to thoroughly test this library with their specific hardware and configurations before deployment.

This library depends on the Zaber Motion Library. Compatibility and performance depend on the proper installation and operation of these third-party components.

This library is an independent implementation based on publicly available documentation from Zaber. It is not affiliated with, endorsed by, or officially supported by Zaber Technologies Inc.

Use this library at your own risk. Proper operation of hardware and compliance with applicable laws and regulations is the sole responsibility of the user.

This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for details.


## Funding
Development has been supported in part by the National Cancer Institute of the National Institutes of Health under award number R01CA249151.

The content of this repository is solely the responsibility of the authors and does not necessarily represent the official views of the National Institutes of Health.